You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@maven.apache.org by "Mark Howard (JIRA)" <ji...@codehaus.org> on 2013/11/07 18:33:52 UTC

[jira] (MEAR-160) Performance regression while copying artifacts into ear

    [ https://jira.codehaus.org/browse/MEAR-160?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=335360#comment-335360 ] 

Mark Howard commented on MEAR-160:
----------------------------------

I've also found this problem on my projects, 30s with 2.8, 8s with 2.9-SNAPSHOT, not with any unpacking.

With the attached project I am seeing a good improvement:
2.8  51s
2.9-SNAPSHOT 19.232s

Is it possible to get a release of 2.9 with the improvements so far?

                
> Performance regression while copying artifacts into ear
> -------------------------------------------------------
>
>                 Key: MEAR-160
>                 URL: https://jira.codehaus.org/browse/MEAR-160
>             Project: Maven Ear Plugin
>          Issue Type: Bug
>    Affects Versions: 2.8
>         Environment: Intel Core i3 : Arch Linux 64-bit : Kernel 3.6.2 : ext4 filesystem : JDK 7u9
>            Reporter: Joseph Freeman
>            Assignee: Olivier Lamy
>             Fix For: 2.9
>
>         Attachments: test.zip
>
>
> Just upgraded the maven ear plugin from 2.7 to 2.8 and it's now taking double the time to build my project. The time increase happens when my jars and war are being copied into the ear as unpacked artifacts. Packed artifacts are still just as fast as before
> Time Comparisons:
> v2.7:
>  * unpacked => 24 seconds
>  * packed   => 21 seconds
> v2.8:
>  * unpacked => 49 seconds
>  * packed   => 20 seconds

--
This message is automatically generated by JIRA.
If you think it was sent incorrectly, please contact your JIRA administrators
For more information on JIRA, see: http://www.atlassian.com/software/jira